#ifndef LDPCENCODING_H_
#define LDPCENCODING_H_
#include "ucps2.h"

MPU_ENTRY void LDPCEnCoding64BG1Asm(v16u32 src);
MPU_ENTRY void LDPCEnCoding64BG2Asm(v16u32 src);
MPU_ENTRY void LDPCEnCoding384PreAsm(v16u32 src);
MPU_ENTRY void LDPCEnCoding384BG1Asm(v16u32 src);
MPU_ENTRY void LDPCEnCoding384BG2Asm(v16u32 src);

void Ldpc64BG1(int* ConfigBaseAddr, int InputAddr,int Zclen,int HMatrixAddr,int TempAddr0,int TempAddr1,int TempAddr2);
void Ldpc64BG2(int* ConfigBaseAddr, int InputAddr,int Zclen,int HMatrixAddr,int TempAddr0,int TempAddr1,int TempAddr2);
void Ldpc384Pre(int* ConfigBaseAddr,int InputAddr,int Zclen,int Basegraph,int OutputAddr0,int OutputAddr1);
void Ldpc384BG1(int* ConfigBaseAddr,int InputAddr0,int InputAddr1,int InputAddr2,int Zclen);
void Ldpc384BG2(int* ConfigBaseAddr,int InputAddr0,int InputAddr1,int InputAddr2,int Zclen);

#endif /* LDPCENCODING_H_ */
